@@ -2,7 +2,6 @@
 # Use of this file is governed by the BSD 3-clause license that
 # can be found in the LICENSE.txt file in the project root.
 #/
-from uuid import UUID
 from io import StringIO
 from typing import Callable
 from antlr4.Token import Token
@@ -13,64 +12,26 @@ from antlr4.atn.Transition import *
 from antlr4.atn.LexerAction import *
 from antlr4.atn.ATNDeserializationOptions import ATNDeserializationOptions
 
-# This is the earliest supported serialized UUID.
-BASE_SERIALIZED_UUID = UUID("AADB8D7E-AEEF-4415-AD2B-8204D6CF042E")
-
-# This UUID indicates the serialized ATN contains two sets of
-# IntervalSets, where the second set's values are encoded as
-# 32-bit integers to support the full Unicode SMP range up to U+10FFFF.
-ADDED_UNICODE_SMP = UUID("59627784-3BE5-417A-B9EB-8131A7286089")
-
-# This list contains all of the currently supported UUIDs, ordered by when
-# the feature first appeared in this branch.
-SUPPORTED_UUIDS = [ BASE_SERIALIZED_UUID, ADDED_UNICODE_SMP ]
-
-SERIALIZED_VERSION = 3
-
-# This is the current serialized UUID.
-SERIALIZED_UUID = ADDED_UNICODE_SMP
+SERIALIZED_VERSION = 4
 
 class ATNDeserializer (object):
+    __slots__ = ('deserializationOptions', 'data', 'pos')
 
     def __init__(self, options : ATNDeserializationOptions = None):
         if options is None:
             options = ATNDeserializationOptions.defaultOptions
         self.deserializationOptions = options
 
-    # Determines if a particular serialized representation of an ATN supports
-    # a particular feature, identified by the {@link UUID} used for serializing
-    # the ATN at the time the feature was first introduced.
-    #
-    # @param feature The {@link UUID} marking the first time the feature was
-    # supported in the serialized ATN.
-    # @param actualUuid The {@link UUID} of the actual serialized ATN which is
-    # currently being deserialized.
-    # @return {@code true} if the {@code actualUuid} value represents a
-    # serialized ATN at or after the feature identified by {@code feature} was
-    # introduced; otherwise, {@code false}.
-
-    def isFeatureSupported(self, feature : UUID , actualUuid : UUID ):
-        idx1 = SUPPORTED_UUIDS.index(feature)
-        if idx1<0:
-            return False
-        idx2 = SUPPORTED_UUIDS.index(actualUuid)
-        return idx2 >= idx1
-
-    def deserialize(self, data : str):
-        self.reset(data)
+    def deserialize(self, data : int):
+        self.data = data
+        self.pos = 0
         self.checkVersion()
-        self.checkUUID()
         atn = self.readATN()
         self.readStates(atn)
         self.readRules(atn)
         self.readModes(atn)
         sets = []
-        # First, read all sets with 16-bit Unicode code points <= U+FFFF.
-        self.readSets(atn, sets, self.readInt)
-        # Next, if the ATN was serialized with the Unicode SMP feature,
-        # deserialize sets with 32-bit arguments <= U+10FFFF.
-        if self.isFeatureSupported(ADDED_UNICODE_SMP, self.uuid):
-            self.readSets(atn, sets, self.readInt32)
+        self.readSets(atn, sets)
         self.readEdges(atn, sets)
         self.readDecisions(atn)
         self.readLexerActions(atn)
@@ -83,28 +44,11 @@ class ATNDeserializer (object):
             self.verifyATN(atn)
         return atn
 
-    def reset(self, data:str):
-        def adjust(c):
-            v = ord(c)
-            return v-2 if v>1 else v + 65533
-        temp = [ adjust(c) for c in data ]
-        # don't adjust the first value since that's the version number
-        temp[0] = ord(data[0])
-        self.data = temp
-        self.pos = 0
-
     def checkVersion(self):
         version = self.readInt()
         if version != SERIALIZED_VERSION:
             raise Exception("Could not deserialize ATN with version " + str(version) + " (expected " + str(SERIALIZED_VERSION) + ").")
 
-    def checkUUID(self):
-        uuid = self.readUUID()
-        if not uuid in SUPPORTED_UUIDS:
-            raise Exception("Could not deserialize ATN with UUID: " + str(uuid) + \
-                            " (expected " + str(SERIALIZED_UUID) + " or a legacy UUID).", uuid, SERIALIZED_UUID)
-        self.uuid = uuid
-
     def readATN(self):
         idx = self.readInt()
         grammarType = ATNType.fromOrdinal(idx)
@@ -122,9 +66,6 @@ class ATNDeserializer (object):
                 atn.addState(None)
                 continue
             ruleIndex = self.readInt()
-            if ruleIndex == 0xFFFF:
-                ruleIndex = -1
-
             s = self.stateFactory(stype, ruleIndex)
             if stype == ATNState.LOOP_END: # special case
                 loopBackStateNumber = self.readInt()
@@ -164,9 +105,6 @@ class ATNDeserializer (object):
             atn.ruleToStartState[i] = startState
             if atn.grammarType == ATNType.LEXER:
                 tokenType = self.readInt()
-                if tokenType == 0xFFFF:
-                    tokenType = Token.EOF
-
                 atn.ruleToTokenType[i] = tokenType
 
         atn.ruleToStopState = [0] * nrules
@@ -182,7 +120,7 @@ class ATNDeserializer (object):
             s = self.readInt()
             atn.modeToStartState.append(atn.states[s])
 
-    def readSets(self, atn:ATN, sets:list, readUnicode:Callable[[], int]):
+    def readSets(self, atn:ATN, sets:list):
         m = self.readInt()
         for i in range(0, m):
             iset = IntervalSet()
@@ -192,8 +130,8 @@ class ATNDeserializer (object):
             if containsEof!=0:
                 iset.addOne(-1)
             for j in range(0, n):
-                i1 = readUnicode()
-                i2 = readUnicode()
+                i1 = self.readInt()
+                i2 = self.readInt()
                 iset.addRange(range(i1, i2 + 1)) # range upper limit is exclusive
 
     def readEdges(self, atn:ATN, sets:list):
@@ -258,11 +196,7 @@ class ATNDeserializer (object):
             for i in range(0, count):
                 actionType = self.readInt()
                 data1 = self.readInt()
-                if data1 == 0xFFFF:
-                    data1 = -1
                 data2 = self.readInt()
-                if data2 == 0xFFFF:
-                    data2 = -1
                 lexerAction = self.lexerActionFactory(actionType, data1, data2)
                 atn.lexerActions[i] = lexerAction
 
@@ -432,22 +366,6 @@ class ATNDeserializer (object):
         self.pos += 1
         return i
 
-    def readInt32(self):
-        low = self.readInt()
-        high = self.readInt()
-        return low | (high << 16)
-
-    def readLong(self):
-        low = self.readInt32()
-        high = self.readInt32()
-        return (low & 0x00000000FFFFFFFF) | (high << 32)
-
-    def readUUID(self):
-        low = self.readLong()
-        high = self.readLong()
-        allBits = (low & 0xFFFFFFFFFFFFFFFF) | (high << 64)
-        return UUID(int=allBits)
-
     edgeFactories = [ lambda args : None,
                       lambda atn, src, trg, arg1, arg2, arg3, sets, target : EpsilonTransition(target),
                       lambda atn, src, trg, arg1, arg2, arg3, sets, target : \
